=========
pulsarbat
=========

.. image:: https://img.shields.io/pypi/v/pulsarbat.svg
        :target: https://pypi.python.org/pypi/pulsarbat

.. image:: https://img.shields.io/pypi/pyversions/cookiecutter.svg
        :target: https://pypi.python.org/pypi/pulsarbat

.. image:: https://img.shields.io/travis/theXYZT/pulsarbat.svg
        :target: https://travis-ci.org/theXYZT/pulsarbat

.. image:: https://codecov.io/gh/theXYZT/pulsarbat/branch/master/graph/badge.svg?token=Ia6qdZNhHE
        :target: https://codecov.io/gh/theXYZT/pulsarbat

.. image:: https://readthedocs.org/projects/pulsarbat/badge/?version=latest
        :target: https://pulsarbat.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


Pulsarbat (Pulsar Baseband Analysis Tools) is a package for analysis of baseband observations of pulsars.

For installation instructions, see the `online documentation <https://pulsarbat.readthedocs.io/>`_ or  `docs/install.rst <docs/install.rst>`_ in this source distribution.

| The source code can be found on GitHub: https://github.com/theXYZT/pulsarbat
| For documentation, please go to: https://pulsarbat.readthedocs.io


Requirements
------------

- **Python 3.8** or later
- `Astropy <https://www.astropy.org/>`_ v4.0 or later
- `Numpy <https://www.numpy.org/>`_ v1.18 or later
- `Scipy <https://scipy.org/>`_ v1.14 or later


License
-------

Pulsarbat is licensed under the GNU General Public License v3.


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
